==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V7/CustomerManagementService/TimeZoneType.pm <==
package Microsoft::AdCenter::V7::CustomerManagementService::TimeZoneType;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

sub AbuDhabiMuscat {
    return 'AbuDhabiMuscat';
}

sub Adelaide {
    return 'Adelaide';
}

sub Alaska {
    return 'Alaska';
}

sub AlmatyNovosibirsk {
    return 'AlmatyNovosibirsk';
}

sub AmsterdamBerlinBernRomeStockholmVienna {
    return 'AmsterdamBerlinBernRomeStockholmVienna';
}

sub Arizona {
    return 'Arizona';
}

sub AstanaDhaka {
    return 'AstanaDhaka';
}

sub AthensBuckarestIstanbul {
    return 'AthensBuckarestIstanbul';
}

sub AtlanticTimeCanada {
    return 'AtlanticTimeCanada';
}

sub AucklandWellington {
    return 'AucklandWellington';
}

sub Azores {
    return 'Azores';
}

sub Baghdad {
    return 'Baghdad';
}

sub BakuTbilisiYerevan {
    return 'BakuTbilisiYerevan';
}

sub BangkokHanoiJakarta {
    return 'BangkokHanoiJakarta';
}

sub BeijingChongqingHongKongUrumqi {
    return 'BeijingChongqingHongKongUrumqi';
}

sub BelgradeBratislavaBudapestLjubljanaPrague {
    return 'BelgradeBratislavaBudapestLjubljanaPrague';
}

sub BogotaLimaQuito {
    return 'BogotaLimaQuito';
}

sub Brasilia {
    return 'Brasilia';
}

sub Brisbane {
    return 'Brisbane';
}

sub BrusselsCopenhagenMadridParis {
    return 'BrusselsCopenhagenMadridParis';
}

sub Bucharest {
    return 'Bucharest';
}

sub BuenosAiresGeorgetown {
    return 'BuenosAiresGeorgetown';
}

sub Cairo {
    return 'Cairo';
}

sub CanberraMelbourneSydney {
    return 'CanberraMelbourneSydney';
}

sub CapeVerdeIsland {
    return 'CapeVerdeIsland';
}

sub CaracasLaPaz {
    return 'CaracasLaPaz';
}

sub CasablancaMonrovia {
    return 'CasablancaMonrovia';
}

sub CentralAmerica {
    return 'CentralAmerica';
}

sub CentralTimeUSCanada {
    return 'CentralTimeUSCanada';
}

sub ChennaiKolkataMumbaiNewDelhi {
    return 'ChennaiKolkataMumbaiNewDelhi';
}

sub ChihuahuaLaPazMazatlan {
    return 'ChihuahuaLaPazMazatlan';
}

sub Darwin {
    return 'Darwin';
}

sub EasternTimeUSCanada {
    return 'EasternTimeUSCanada';
}

sub Ekaterinburg {
    return 'Ekaterinburg';
}

sub FijiKamchatkaMarshallIsland {
    return 'FijiKamchatkaMarshallIsland';
}

sub Greenland {
    return 'Greenland';
}

sub GreenwichMeanTimeDublinEdinburghLisbonLondon {
    return 'GreenwichMeanTimeDublinEdinburghLisbonLondon';
}

sub GuadalajaraMexicoCityMonterrey {
    return 'GuadalajaraMexicoCityMonterrey';
}

sub GuamPortMoresby {
    return 'GuamPortMoresby';
}

sub HararePretoria {
    return 'HararePretoria';
}

sub Hawaii {
    return 'Hawaii';
}

sub HelsinkiKyivRigaSofiaTallinnVilnius {
    return 'HelsinkiKyivRigaSofiaTallinnVilnius';
}

sub Hobart {
    return 'Hobart';
}

sub IndianaEast {
    return 'IndianaEast';
}

sub InternationalDatelineWest {
    return 'InternationalDatelineWest';
}

sub IrkutskUlaanBataar {
    return 'IrkutskUlaanBataar';
}

sub IslamabadKarachiTashkent {
    return 'IslamabadKarachiTashkent';
}

sub Jerusalem {
    return 'Jerusalem';
}

sub Kabul {
    return 'Kabul';
}

sub Kathmandu {
    return 'Kathmandu';
}

sub Krasnoyarsk {
    return 'Krasnoyarsk';
}

sub KualaLumpurSingapore {
    return 'KualaLumpurSingapore';
}

sub KuwaitRiyadh {
    return 'KuwaitRiyadh';
}

sub MagadanSolomonIslandNewCaledonia {
    return 'MagadanSolomonIslandNewCaledonia';
}

sub MidAtlantic {
    return 'MidAtlantic';
}

sub MidwayIslandAndSamoa {
    return 'MidwayIslandAndSamoa';
}

sub MoscowStPetersburgVolgograd {
    return 'MoscowStPetersburgVolgograd';
}

sub MountainTimeUSCanada {
    return 'MountainTimeUSCanada';
}

sub Nairobi {
    return 'Nairobi';
}

sub Newfoundland {
    return 'Newfoundland';
}

sub Nukualofa {
    return 'Nukualofa';
}

sub OsakaSapporoTokyo {
    return 'OsakaSapporoTokyo';
}

sub PacificTimeUSCanadaTijuana {
    return 'PacificTimeUSCanadaTijuana';
}

sub Perth {
    return 'Perth';
}

sub Rangoon {
    return 'Rangoon';
}

sub Santiago {
    return 'Santiago';
}

sub SarajevoSkopjeWarsawZagreb {
    return 'SarajevoSkopjeWarsawZagreb';
}

sub Saskatchewan {
    return 'Saskatchewan';
}

sub Seoul {
    return 'Seoul';
}

sub SriJayawardenepura {
    return 'SriJayawardenepura';
}

sub Taipei {
    return 'Taipei';
}

sub Tehran {
    return 'Tehran';
}

sub Vladivostok {
    return 'Vladivostok';
}

sub WestCentralAfrica {
    return 'WestCentralAfrica';
}

sub Yakutsk {
    return 'Yakutsk';
}

1;

==> Microsoft-AdCenter-8.00_02.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V7/CustomerManagementService/TimeZoneType.pm <==
package Microsoft::AdCenter::V7::CustomerManagementService::TimeZoneType;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V7::CustomerManagementService::TimeZoneType - Represents "TimeZoneType" in Microsoft AdCenter Customer Management Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

AbuDhabiMuscat
Adelaide
Alaska
AlmatyNovosibirsk
AmsterdamBerlinBernRomeStockholmVienna
Arizona
AstanaDhaka
AthensBuckarestIstanbul
AtlanticTimeCanada
AucklandWellington
Azores
Baghdad
BakuTbilisiYerevan
BangkokHanoiJakarta
BeijingChongqingHongKongUrumqi
BelgradeBratislavaBudapestLjubljanaPrague
BogotaLimaQuito
Brasilia
Brisbane
BrusselsCopenhagenMadridParis
Bucharest
BuenosAiresGeorgetown
Cairo
CanberraMelbourneSydney
CapeVerdeIsland
CaracasLaPaz
CasablancaMonrovia
CentralAmerica
CentralTimeUSCanada
ChennaiKolkataMumbaiNewDelhi
ChihuahuaLaPazMazatlan
Darwin
EasternTimeUSCanada
Ekaterinburg
FijiKamchatkaMarshallIsland
Greenland
GreenwichMeanTimeDublinEdinburghLisbonLondon
GuadalajaraMexicoCityMonterrey
GuamPortMoresby
HararePretoria
Hawaii
HelsinkiKyivRigaSofiaTallinnVilnius
Hobart
IndianaEast
InternationalDatelineWest
IrkutskUlaanBataar
IslamabadKarachiTashkent
Jerusalem
Kabul
Kathmandu
Krasnoyarsk
KualaLumpurSingapore
KuwaitRiyadh
MagadanSolomonIslandNewCaledonia
MidAtlantic
MidwayIslandAndSamoa
MoscowStPetersburgVolgograd
MountainTimeUSCanada
Nairobi
Newfoundland
Nukualofa
OsakaSapporoTokyo
PacificTimeUSCanadaTijuana
Perth
Rangoon
Santiago
SarajevoSkopjeWarsawZagreb
Saskatchewan
Seoul
SriJayawardenepura
Taipei
Tehran
Vladivostok
WestCentralAfrica
Yakutsk

=cut

sub AbuDhabiMuscat {
    return 'AbuDhabiMuscat';
}

sub Adelaide {
    return 'Adelaide';
}

sub Alaska {
    return 'Alaska';
}

sub AlmatyNovosibirsk {
    return 'AlmatyNovosibirsk';
}

sub AmsterdamBerlinBernRomeStockholmVienna {
    return 'AmsterdamBerlinBernRomeStockholmVienna';
}

sub Arizona {
    return 'Arizona';
}

sub AstanaDhaka {
    return 'AstanaDhaka';
}

sub AthensBuckarestIstanbul {
    return 'AthensBuckarestIstanbul';
}

sub AtlanticTimeCanada {
    return 'AtlanticTimeCanada';
}

sub AucklandWellington {
    return 'AucklandWellington';
}

sub Azores {
    return 'Azores';
}

sub Baghdad {
    return 'Baghdad';
}

sub BakuTbilisiYerevan {
    return 'BakuTbilisiYerevan';
}

sub BangkokHanoiJakarta {
    return 'BangkokHanoiJakarta';
}

sub BeijingChongqingHongKongUrumqi {
    return 'BeijingChongqingHongKongUrumqi';
}

sub BelgradeBratislavaBudapestLjubljanaPrague {
    return 'BelgradeBratislavaBudapestLjubljanaPrague';
}

sub BogotaLimaQuito {
    return 'BogotaLimaQuito';
}

sub Brasilia {
    return 'Brasilia';
}

sub Brisbane {
    return 'Brisbane';
}

sub BrusselsCopenhagenMadridParis {
    return 'BrusselsCopenhagenMadridParis';
}

sub Bucharest {
    return 'Bucharest';
}

sub BuenosAiresGeorgetown {
    return 'BuenosAiresGeorgetown';
}

sub Cairo {
    return 'Cairo';
}

sub CanberraMelbourneSydney {
    return 'CanberraMelbourneSydney';
}

sub CapeVerdeIsland {
    return 'CapeVerdeIsland';
}

sub CaracasLaPaz {
    return 'CaracasLaPaz';
}

sub CasablancaMonrovia {
    return 'CasablancaMonrovia';
}

sub CentralAmerica {
    return 'CentralAmerica';
}

sub CentralTimeUSCanada {
    return 'CentralTimeUSCanada';
}

sub ChennaiKolkataMumbaiNewDelhi {
    return 'ChennaiKolkataMumbaiNewDelhi';
}

sub ChihuahuaLaPazMazatlan {
    return 'ChihuahuaLaPazMazatlan';
}

sub Darwin {
    return 'Darwin';
}

sub EasternTimeUSCanada {
    return 'EasternTimeUSCanada';
}

sub Ekaterinburg {
    return 'Ekaterinburg';
}

sub FijiKamchatkaMarshallIsland {
    return 'FijiKamchatkaMarshallIsland';
}

sub Greenland {
    return 'Greenland';
}

sub GreenwichMeanTimeDublinEdinburghLisbonLondon {
    return 'GreenwichMeanTimeDublinEdinburghLisbonLondon';
}

sub GuadalajaraMexicoCityMonterrey {
    return 'GuadalajaraMexicoCityMonterrey';
}

sub GuamPortMoresby {
    return 'GuamPortMoresby';
}

sub HararePretoria {
    return 'HararePretoria';
}

sub Hawaii {
    return 'Hawaii';
}

sub HelsinkiKyivRigaSofiaTallinnVilnius {
    return 'HelsinkiKyivRigaSofiaTallinnVilnius';
}

sub Hobart {
    return 'Hobart';
}

sub IndianaEast {
    return 'IndianaEast';
}

sub InternationalDatelineWest {
    return 'InternationalDatelineWest';
}

sub IrkutskUlaanBataar {
    return 'IrkutskUlaanBataar';
}

sub IslamabadKarachiTashkent {
    return 'IslamabadKarachiTashkent';
}

sub Jerusalem {
    return 'Jerusalem';
}

sub Kabul {
    return 'Kabul';
}

sub Kathmandu {
    return 'Kathmandu';
}

sub Krasnoyarsk {
    return 'Krasnoyarsk';
}

sub KualaLumpurSingapore {
    return 'KualaLumpurSingapore';
}

sub KuwaitRiyadh {
    return 'KuwaitRiyadh';
}

sub MagadanSolomonIslandNewCaledonia {
    return 'MagadanSolomonIslandNewCaledonia';
}

sub MidAtlantic {
    return 'MidAtlantic';
}

sub MidwayIslandAndSamoa {
    return 'MidwayIslandAndSamoa';
}

sub MoscowStPetersburgVolgograd {
    return 'MoscowStPetersburgVolgograd';
}

sub MountainTimeUSCanada {
    return 'MountainTimeUSCanada';
}

sub Nairobi {
    return 'Nairobi';
}

sub Newfoundland {
    return 'Newfoundland';
}

sub Nukualofa {
    return 'Nukualofa';
}

sub OsakaSapporoTokyo {
    return 'OsakaSapporoTokyo';
}

sub PacificTimeUSCanadaTijuana {
    return 'PacificTimeUSCanadaTijuana';
}

sub Perth {
    return 'Perth';
}

sub Rangoon {
    return 'Rangoon';
}

sub Santiago {
    return 'Santiago';
}

sub SarajevoSkopjeWarsawZagreb {
    return 'SarajevoSkopjeWarsawZagreb';
}

sub Saskatchewan {
    return 'Saskatchewan';
}

sub Seoul {
    return 'Seoul';
}

sub SriJayawardenepura {
    return 'SriJayawardenepura';
}

sub Taipei {
    return 'Taipei';
}

sub Tehran {
    return 'Tehran';
}

sub Vladivostok {
    return 'Vladivostok';
}

sub WestCentralAfrica {
    return 'WestCentralAfrica';
}

sub Yakutsk {
    return 'Yakutsk';
}

1;
